searchNodes=[{"doc":"Runs mix test on the latest git commit, plus any staged changes. Performs the following steps: Creates a temporary directory (in the standard system location). Runs git diff --cached (in the local tree) to extract staged changes. Clones the local tree into the temporary directory. Applies the changes extracted in step 2. Symlinks dependencies build directories from the local tree to cloned tree. This avoids needing to recompile dependencies, which aren't part of the check-in anyway. Runs mix test , capturing the output (both stdout and stderr). If it passes, great! If it fails, dumps the captured output and exits with a non-zero status. Cleans up the temporary directory on exit. This is intended to be used as part of a pre-commit hook, to help protect against forgetting to add new files, doing partial commits where some committed changes depend on changes not staged for commit, etc. This task must be run in the test environment, i.e. with MIX_ENV=test . In order to perform step 5, it needs an accurate list of dependency build directories for the environment it will be testing in. (Also, running the task itself in the test environment ensures that all dependencies will have been built beforehand.) Use mix git.test.install to install the default pre-commit hook.","ref":"Mix.Tasks.Git.Test.html","title":"Mix.Tasks.Git.Test","type":"task"},{"doc":"Installs a git pre-commit hook to ensure mix git.test passes before allowing a commit. The actual contents of the hook are incredibly simple: #!/bin/sh MIX_ENV=test exec mix git.test The hook will be installed as .git/hooks/pre-commit . If that file already exists, it will not be overwritten; instead, this task will report whether the existing hook appears to contain mix git.test or not.","ref":"Mix.Tasks.Git.Test.Install.html","title":"Mix.Tasks.Git.Test.Install","type":"task"},{"doc":"Automatically run mix test before committing, but only on your staged changes.","ref":"readme.html","title":"mix git.test","type":"extras"},{"doc":"We've all had those moments where we push a commit that breaks the test suite. Maybe you even ran the test suite first (and passed), but you added a new file and forgot to git add it. Or maybe you're intentionally doing a partial commit, and you thought you got all the relevant changes, but one of them slipped through. Or maybe you've got local .gitignore d files that your build accidentally relies on. mix git.test aims to solve this by (efficiently) cloning your work tree to a temporary directory, applying only the specific changes you're planning on committing, running the test suite there, and seeing if your tests pass on a &quot;clean&quot; build. It's meant to be included in a git pre-commit hook, to automatically run every commit, and abort the commit if an error occurs. Decently fast (for small projects, anyway) To keep this quick, we take one major shortcut — the cloned tree's dependencies will be symbolic links to the working tree's dependencies, to avoid recompiling them. While this doesn't normally cause any issues, you'll want to keep this in mind if you're doing anything weird like directly editing your deps tree. That said, you're still looking at however long it takes to do a full compile and run your test suite. If you've got a massive project that takes several minutes to compile and test, you'll probably want to give this library a pass!","ref":"readme.html#clean-and-reliable-testing","title":"mix git.test - Clean and reliable testing","type":"extras"},{"doc":"","ref":"readme.html#demo","title":"mix git.test - Demo","type":"extras"},{"doc":"First, add ex_git_test to your list of dependencies in mix.exs : def deps do [ { :ex_git_test , &quot;~&gt; 0.1.1&quot; , only : [ :dev , :test ] , runtime : false } ] end Now fetch your dependencies with mix deps.get , and then test things with MIX_ENV=test mix git.test . Hopefully everything passes. (If it has issues with the state of your tree, try committing your existing changes first.) Next, run mix git.test.install . This will create an executable .git/hooks/pre-commit file that runs mix git.test for you. (This will not overwrite an existing pre-commit hook. You can either move your existing hook out of the way, or just integrate mix git.test into your existing one.) Feel free to customise your new hook however you want. The most important thing is just to ensure that if mix git.test fails, then the hook exits with a non-zero status. The default script uses exec for this, but you could also do the equivalent of mix git.test || exit 1 . (Make sure you test your hook by staging some changes that deliberately break the tests and seeing if git lets you commit them.)","ref":"readme.html#setup","title":"mix git.test - Setup","type":"extras"},{"doc":"Full documentation can be found at https://hexdocs.pm/ex_git_test . Once installed, you can also run mix help git.test and mix help git.test.install .","ref":"readme.html#documentation","title":"mix git.test - Documentation","type":"extras"},{"doc":"Copyright © 2023, Adrian Irving-Beer. ex_git_test is released under the MIT license and is provided with no warranty .","ref":"readme.html#legal-stuff","title":"mix git.test - Legal stuff","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"Updated the README to reflect the MIX_ENV=test requirement. No code changes, just bumping the version to ensure the Hex docs are updated.","ref":"changelog.html#v0-1-2","title":"Changelog - v0.1.2","type":"extras"},{"doc":"Changelog created. Ensure git.test is run in the test env. This is required to ensure dependency build linking works correctly.","ref":"changelog.html#v0-1-1","title":"Changelog - v0.1.1","type":"extras"}]